<?php

define('URL_BASE', 'sbpickleball.club');
define("SITE_SLUG", 'ce_open');
define('CLUB_ID', 886618);
define('REAL', 1);                          //debug test #############################################
define('LOG', 1);                          //debug test #############################################
define('DEBUG', 1);                          //debug test #############################################
define('STORE_HTML', 0);
define('READ_HTML', 0);
define('NUMBER_TO_MEMBER_NUMBER_CSV', 'ce_number_to_member_spa');
define('BOOKING_DAYS_IN_ADVANCE', 7);       //7 start booking this many days in the future
define('DEFAULT_RELEASE_TIME', '13:00:00');
define('HOLD_MESSAGE', 'Reserve at 1PM Today');
define("DELAYS", 1);    //debug test #############################################

require_once 'clubexpress_schedule_class.php';

echo date('Y-m-d H:i:s') . " Start of run\n";
$test = date_default_timezone_set('America/Phoenix');
echo date('Y-m-d H:i:s') . " After timezone change - result $test \n";
$DIR = __DIR__ . '/';       //get the root directory and pass it on to all the functions

$control_str['username'] = 'jtest';
$control_str['password'] = 'PickleSPA23#';
$control_str['human_name'] = 'Members Can';
$control_str['name'] = 'open';

$class = initialize_users($control_str);        //initialize admin account

//convert the cli arguments to an associative array
$args = getopt("hd:t:");

if (isset($args['h'])) {
    displayHelp();
}

do_temp_open($control_str, $args);

function do_temp_open($control_str, $args)
{
    global $DIR, $class;

    $now = time();
    //$now = strtotime('2024-05-20 13:59:01');  //debug test #############################################

    $today = date('Y-m-d', $now);

    $class->log_message(("Start of daily run"), true, false);
    if(isset($args['d'])) {
        //a date was specified so use it
        $date = $args['d'];
        $date_unix = strtotime($date);
        if(!$date_unix) {
            //invalid date
            $class->log_message("Invalid date: $date", true);
            $class->log_result();
            return;
        }
    }
    else {
        $date_unix = $now + (BOOKING_DAYS_IN_ADVANCE * 86400);     //point 8 days into the future
        $date = date('Y-m-d', $date_unix);        //convert to human date
    }

    if(isset($args['t'])) {
        //a time was specified so use it
        $time = $args['t'];
        $time_unix = strtotime($time);
        if(!$time_unix) {
            //invalid time
            $class->log_message("Invalid time: $time", true);
            $class->log_result();
            return;
        }
    }
    elseif(isset($args['d'])) {
        //a date was specified but no time to do it now
        $time = date('H:i:s', ($now - 1));
    }
    else {
        $time = DEFAULT_RELEASE_TIME;
    }

    $action_time = $today . ' ' . $time;
    $action_time_unix = strtotime($action_time);

    if($now < $action_time_unix) {
        $delay = $action_time_unix - $now;
        $class->log_message("Delaying $delay seconds until $action_time releasing courts for $date", true);
        if(DELAYS) {
            sleep($delay);
        }
    }


    $logged_in = $class->login(true);         //login as admin
    if (!$logged_in) {
        //login failed so no use continuing
        $class->log_message("Login Failed: {$control_str['username']} / {$control_str['password']}", true);
        $class->log_result();
        return;
    }


    $location_index = $class->getLocationIndex($date);
    $ce_members = $class->getCeMemberNumbers(NUMBER_TO_MEMBER_NUMBER_CSV, false);
    open_closed_courts($date, $location_index);

    $class->log_message(("End of Run"), true, false);
    $class->log_result();       //file the results of the day's run
}

function open_closed_courts($date, $location_index)
{
    global $class;

    $human_name = $class->human_name;
    $total_count = 0;
    $loops = -1;
    do {
        $reservations = $class->getCalendar($date, $location_index);
        $count = 0;
        foreach ($reservations as $time_str => $courts) {
            foreach ($courts as $court_id => $values) {
                if (isset($values['booking'])) {
                    //court booked so if it is booked by this login
                    $human_name_this = trim(html_entity_decode($values['booking']->userName));
                    if ($human_name_this == $human_name) {
                        $success_cancel = $class->cancelReservation($values['booking']->id, $location_index);    //actually cancel the event
                        if (!$success_cancel) {
                            //the cancel failed
                            $class->log_message("***COURT RELEASE FAILED***  ON $date AT $time_str COURT  $court_id ERROR: $success_cancel", true, false);
                        } else {
                            $class->log_message("SUCCESSFULLY RELEASED: $date AT $time_str COURT  $court_id", true, false);
                            $count++;
                            $total_count++;
                        }
                    }
                }
            }
        }
        $loops++;
    } while($count);
    $class->log_message("SUCCESSFULLY RELEASED $total_count courts in $loops loops on $date", true, false);
}



function initialize_users($values) {
    global $DIR;


    $log = LOG;
    $debug = DEBUG;
    $store_html = STORE_HTML;
    $read_html = READ_HTML;
    $class = array();
    $class = new Clubexpress_class($values['username'], $values['password'], $values['name'], $DIR, $values['human_name'], $log, $debug, $read_html, $store_html);

    return $class;
}

/**
 * Show the help message and exit
 */
function displayHelp()
{
    global $argv;
    echo "This program releases all courts that are on hold 8 days in advance:\n";
    echo "Usage: {$argv[0]} <options>\n\n";
    echo " Options:\n";
    echo "    -d <string> date <string> for the courts to be released\n";
    echo "    -t <string> time <string> time of day to release the courts\n\n";
    echo "Example: -d 2023-03-23 -t 13:00 //release courts for 2023-03-23 and release them today at 13:00\n";
    echo "\n\n";

    exit;
}









